@@ -117,3 +117,17 @@ sub _TestMockifyObject {
 }
 
 1;
+__END__
+
+=head1 LICENSE
+
+Copyright (C) 2017 ePages GmbH
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=head1 AUTHOR
+
+Christian Breitkreutz E<lt>cbreitkreutz@epages.comE<gt>
+
+=cut
\ No newline at end of file
